//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithoutGot](index.md)/[ShantenWithoutGot](-shanten-without-got.md)

# ShantenWithoutGot

[common]\
constructor(shantenNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html), advance: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;, advanceNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) = 0, goodShapeAdvance: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;? = if (shantenNum == 1) emptySet() else null, goodShapeAdvanceNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)? = if (shantenNum == 1) 0 else null, improvement: [Map](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md), [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Improvement](../-improvement/index.md)&gt;&gt;? = if (shantenNum == 0) emptyMap() else null, improvementNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)? = if (shantenNum == 0) 0 else null, goodShapeImprovement: [Map](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md), [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Improvement](../-improvement/index.md)&gt;&gt;? = if (shantenNum == 0) emptyMap() else null, goodShapeImprovementNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)? = if (shantenNum == 0) 0 else null)
